@@ -2,10 +2,10 @@ from __future__ import unicode_literals
 
 import os
 
-from mopidy import ext, config
+from mopidy import config, ext
 
 
-__version__ = '1.1.0'
+__version__ = '2.0.0'
 
 
 class BeetsExtension(ext.Extension):
